@@ -47,12 +47,17 @@ from astropy.units.core import (
     dimensionless_unscaled,
 )
 from astropy.utils import isiterable
-from astropy.utils.compat import NUMPY_LT_1_22, NUMPY_LT_1_23, NUMPY_LT_2_0
+from astropy.utils.compat import NUMPY_LT_1_23, NUMPY_LT_2_0
+
+if NUMPY_LT_2_0:
+    import numpy.core as np_core
+else:
+    import numpy._core as np_core
 
 # In 1.17, overrides are enabled by default, but it is still possible to
 # turn them off using an environment variable.  We use getattr since it
 # is planned to remove that possibility in later numpy versions.
-ARRAY_FUNCTION_ENABLED = getattr(np.core.overrides, "ENABLE_ARRAY_FUNCTION", True)
+ARRAY_FUNCTION_ENABLED = getattr(np_core.overrides, "ENABLE_ARRAY_FUNCTION", True)
 SUBCLASS_SAFE_FUNCTIONS = set()
 """Functions with implementations supporting subclasses like Quantity."""
 FUNCTION_HELPERS = {}
@@ -76,16 +81,16 @@ SUBCLASS_SAFE_FUNCTIONS |= {
     np.split, np.array_split, np.hsplit, np.vsplit, np.dsplit,
     np.stack, np.column_stack, np.hstack, np.vstack, np.dstack,
     np.max, np.min, np.amax, np.amin, np.ptp, np.sum, np.cumsum,
-    np.prod, np.product, np.cumprod, np.cumproduct,
+    np.prod, np.cumprod,
     np.round, np.around,
-    np.round_,  # Alias for np.round in NUMPY_LT_1_25, but deprecated since.
     np.fix, np.angle, np.i0, np.clip,
     np.isposinf, np.isneginf, np.isreal, np.iscomplex,
     np.average, np.mean, np.std, np.var, np.trace,
     np.nanmax, np.nanmin, np.nanargmin, np.nanargmax, np.nanmean,
     np.nansum, np.nancumsum, np.nanstd, np.nanvar,
     np.nanprod, np.nancumprod,
-    np.einsum_path, np.trapz, np.linspace,
+    np.einsum_path, np.linspace,
+    np.trapz,  # deprecated in not NUMPY_LT_2_0
     np.sort, np.partition, np.meshgrid,
     np.common_type, np.result_type, np.can_cast, np.min_scalar_type,
     np.iscomplexobj, np.isrealobj,
@@ -93,13 +98,18 @@ SUBCLASS_SAFE_FUNCTIONS |= {
     np.apply_along_axis, np.take_along_axis, np.put_along_axis,
     np.linalg.cond, np.linalg.multi_dot,
 }  # fmt: skip
+SUBCLASS_SAFE_FUNCTIONS |= {  # Deprecated
+    np.product, np.cumproduct,  # noqa: NPY003
+}  # fmt: skip
 
-if not NUMPY_LT_1_22:
-    SUBCLASS_SAFE_FUNCTIONS |= {np.median}
+SUBCLASS_SAFE_FUNCTIONS |= {np.median}
 
 if NUMPY_LT_2_0:
-    # functions removed in numpy 2.0
-    SUBCLASS_SAFE_FUNCTIONS |= {np.msort}
+    # functions removed in numpy 2.0; alias for np.round in NUMPY_LT_1_25
+    SUBCLASS_SAFE_FUNCTIONS |= {np.msort, np.round_}  # noqa: NPY003
+else:
+    # Array-API compatible versions (matrix axes always at end).
+    SUBCLASS_SAFE_FUNCTIONS |= {np.linalg.diagonal, np.linalg.trace}
 
 # Implemented as methods on Quantity:
 # np.ediff1d is from setops, but we support it anyway; the others
@@ -110,7 +120,10 @@ UNSUPPORTED_FUNCTIONS |= {
     np.packbits, np.unpackbits, np.unravel_index,
     np.ravel_multi_index, np.ix_, np.cov, np.corrcoef,
     np.busday_count, np.busday_offset, np.datetime_as_string,
-    np.is_busday, np.all, np.any, np.sometrue, np.alltrue,
+    np.is_busday, np.all, np.any,
+}  # fmt: skip
+UNSUPPORTED_FUNCTIONS |= {  # Deprecated
+    np.sometrue, np.alltrue,  # noqa: NPY003
 }  # fmt: skip
 
 # Could be supported if we had a natural logarithm unit.
@@ -177,13 +190,13 @@ dispatched_function = FunctionAssigner(DISPATCHED_FUNCTIONS)
 # fmt: off
 @function_helper(
     helps={
-        np.copy, np.asfarray, np.real_if_close, np.sort_complex, np.resize,
+        np.copy, np.real_if_close, np.sort_complex, np.resize,
         np.fft.fft, np.fft.ifft, np.fft.rfft, np.fft.irfft,
         np.fft.fft2, np.fft.ifft2, np.fft.rfft2, np.fft.irfft2,
         np.fft.fftn, np.fft.ifftn, np.fft.rfftn, np.fft.irfftn,
         np.fft.hfft, np.fft.ihfft,
         np.linalg.eigvals, np.linalg.eigvalsh,
-    }
+    } | ({np.asfarray} if NUMPY_LT_2_0 else set())
 )
 # fmt: on
 def invariant_a_helper(a, *args, **kwargs):
@@ -383,23 +396,6 @@ def _iterable_helper(*args, out=None, **kwargs):
     return arrays, kwargs, unit, out
 
 
-if NUMPY_LT_1_22:
-
-    @function_helper
-    def median(a, axis=None, out=None, overwrite_input=False, keepdims=False):
-        kwargs = {"overwrite_input": overwrite_input, "keepdims": keepdims}
-        if out is not None:
-            from astropy.units import Quantity
-
-            if not isinstance(out, Quantity):
-                raise NotImplementedError
-            # We may get here just because of out, so ensure input is Quantity.
-            a = _as_quantity(a)
-            kwargs["out"] = out.view(np.ndarray)
-
-        return (a.value, axis), kwargs, a.unit, out
-
-
 @function_helper
 def concatenate(arrays, axis=0, out=None, **kwargs):
     # TODO: make this smarter by creating an appropriately shaped
@@ -417,10 +413,10 @@ def block(arrays):
     # arrays and then turn them back into a nested list, we just copy here the
     # second implementation, np.core.shape_base._block_slicing, since it is
     # shortest and easiest.
-    (arrays, list_ndim, result_ndim, final_size) = np.core.shape_base._block_setup(
+    (arrays, list_ndim, result_ndim, final_size) = np_core.shape_base._block_setup(
         arrays
     )
-    shape, slices, arrays = np.core.shape_base._block_info_recursion(
+    shape, slices, arrays = np_core.shape_base._block_info_recursion(
         arrays, list_ndim, result_ndim
     )
     # Here, one line of difference!
@@ -454,7 +450,7 @@ def select(condlist, choicelist, default=0):
 def piecewise(x, condlist, funclist, *args, **kw):
     from astropy.units import Quantity
 
-    # Copied implementation from numpy.lib.function_base.piecewise,
+    # Copied implementation from numpy.lib._function_base_impl.piecewise,
     # taking care of units of function outputs.
     n2 = len(funclist)
     # undocumented: single condition is promoted to a list of one condition
@@ -932,7 +928,7 @@ def twosetop(ar1, ar2, *args, **kwargs):
     return (ar1, ar2) + args, kwargs, unit, None
 
 
-@function_helper(helps=(np.isin, np.in1d))
+@function_helper(helps=(np.isin, np.in1d))  # np.in1d deprecated in not NUMPY_LT_2_0.
 def setcheckop(ar1, ar2, *args, **kwargs):
     # This tests whether ar1 is in ar2, so we should change the unit of
     # a1 to that of a2.
@@ -1013,7 +1009,10 @@ def array2string(a, *args, **kwargs):
         a = a.value
     else:
         # See whether it covers our dtype.
-        from numpy.core.arrayprint import _get_format_function, _make_options_dict
+        if NUMPY_LT_2_0:
+            from numpy.core.arrayprint import _get_format_function, _make_options_dict
+        else:
+            from numpy._core.arrayprint import _get_format_function, _make_options_dict
 
         with np.printoptions(formatter=formatter) as options:
             options = _make_options_dict(**options)
